@@ -3,30 +3,33 @@
 
 from __future__ import absolute_import
 from .. import t1types
-from ..config import PATHS
 from ..entity import Entity
 
 
 class StrategyConcept(Entity):
-    """docstring for StrategyConcept."""
+    """StrategyConcept object to join strategy and concept."""
     collection = 'strategy_concepts'
     resource = 'strategy_concept'
     _relations = {
         'concept',
         'strategy',
     }
+    _weight_types = t1types.enum({'IMPRESSION', 'BUDGET', 'NONE'}, 'NONE')
     _pull = {
         'concept_id': int,
         'created_on': t1types.strpt,
         'id': int,
+        'percent': float,
         'status': t1types.int_to_bool,
         'strategy_id': int,
         'updated_on': t1types.strpt,
         'version': int,
+        'weighting': None,
     }
     _push = _pull.copy()
     _push.update({
         'status': int,
+        'weighting': _weight_types,
     })
     _readonly = Entity._readonly | {'name', }
 
@@ -38,6 +41,6 @@ class StrategyConcept(Entity):
         url = '/'.join([self.collection,
                         str(self.id),
                         'delete'])
-        self._post(PATHS['mgmt'], rest=url, data={'version': self.version})
-        for item in list(self.properties.keys()):
-            del self.properties[item]
+        self._post(self._get_service_path(), rest=url, data={'version': self.version})
+        for item in list(self._properties.keys()):
+            del self._properties[item]
